@@ -105,7 +105,7 @@ def vstructures(dag):
 
 
 # add missing value in dataset
-def add_missing(data, cause_dict, m_min=0.1, m_max=0.6):
+def add_missing(data, cause_dict, m_min=0, m_max=0.5):
     data_missing = deepcopy(data)
     for var in cause_dict.keys():
         m = np.random.uniform(m_min, m_max)
@@ -145,13 +145,11 @@ def pairwise(data, varnames, vars, cause_list, cache_data, cache_weight, method)
         if W not in cache_data:
             W_ids = [i for i in range(len(varnames)) if varnames[i] in W]
             if len(W):
-                if 'int' in data.dtype.name:
-                    cache_data[W] = data[data[:, W_ids].min(axis=1) >= 0]
-                else:
-                    cache_data[W] = data[~np.isnan(data[:, W_ids]).any(axis=1)]
+                cache_data[W] = data[data[:, W_ids].min(axis=1) >= 0] if 'int' in data.dtype.name else data[
+                    ~np.isnan(data[:, W_ids]).any(axis=1)]
             else:
                 cache_data[W] = data
-            cache_weight[W] = np.ones(len(cache_data[W])) * data.shape[0] / len(cache_data[W])
+            cache_weight[W] = np.ones(len(cache_data[W]))
     elif method == 'ipw':
         W = list(vars)
         while True:
@@ -165,12 +163,9 @@ def pairwise(data, varnames, vars, cause_list, cache_data, cache_weight, method)
         if W not in cache_data:
             W_ids = [i for i in range(len(varnames)) if varnames[i] in W]
             if len(W) > 0:
-                if 'int' in data.dtype.name:
-                    cache_data[W] = data[data[:, W_ids].min(axis=1) >= 0]
-                else:
-                    cache_data[W] = data[~np.isnan(data[:, W_ids]).any(axis=1)]
-                cache_weight[W] = compute_weights(data, varnames, W_ids, cause_list) / cache_data[W].shape[0] * \
-                                  data.shape[0]
+                cache_data[W] = data[data[:, W_ids].min(axis=1) >= 0] if 'int' in data.dtype.name else data[
+                    ~np.isnan(data[:, W_ids]).any(axis=1)]
+                cache_weight[W] = compute_weights(data, varnames, W_ids, cause_list)
             else:
                 cache_data[W] = data
                 cache_weight[W] = np.ones(len(data))
@@ -183,16 +178,10 @@ def pairwise(data, varnames, vars, cause_list, cache_data, cache_weight, method)
         if W not in cache_data:
             if len(W) > 0:
                 W_ids = [i for i in range(len(varnames)) if varnames[i] in W]
-                if 'int' in data.dtype.name:
-                    cache_data[W] = data[data[:, W_ids].min(axis=1) >= 0]
-                else:
-                    cache_data[W] = data[~np.isnan(data[:, W_ids]).any(axis=1)]
-
-                if pa_d:
-                    cache_weight[W] = np.ones(cache_data[W].shape[0]) / cache_data[W].shape[0] * data.shape[0]
-                else:
-                    cache_weight[W] = compute_weights(data, varnames, W_ids, cause_list) / cache_data[W].shape[0] * \
-                                      data.shape[0]
+                cache_data[W] = data[data[:, W_ids].min(axis=1) >= 0] if 'int' in data.dtype.name else data[
+                    ~np.isnan(data[:, W_ids]).any(axis=1)]
+                cache_weight[W] = np.ones(cache_data[W].shape[0]) if pa_d else compute_weights(data, varnames, W_ids,
+                                                                                               cause_list)
             else:
                 cache_data[W] = data
                 cache_weight[W] = np.ones(data.shape[0])
@@ -789,4 +778,4 @@ def edges(graph):
         for nei in graph[var]['nei']:
             if len(edge[(edge['from'] == nei) & (edge['to'] == var)]) == 0:
                 edge.loc[len(edge)] = [var, nei, 'undirected']
-    return edge
\ No newline at end of file
+    return edge
